HasCellChannelConfig

Trait HasCellChannelConfig 

pub trait HasCellChannelConfig: Into<u16> + From<u16> {
    // Provided method
    fn set_channel_config(self, config: CellChannelConfig) -> Self { ... }
}
Marks all Commands that have a Channel Config for the cell voltage ADCs and provides method to set the channel config

Provided Methods

fn set_channel_config(self, config: CellChannelConfig) -> Self

Sets the channel config for the cell voltage conversion command. Not setting anything Defaults to CellChannelConfig::AllCells

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors