HasPullUpOption

Trait HasPullUpOption 

pub trait HasPullUpOption: Into<u16> + From<u16> {
    // Provided method
    fn set_pullup_option(self) -> Self { ... }
}

Provided Methods

fn set_pullup_option(self) -> Self

Defines the PullUp or PullDown Option for the Open Wire Check Commands Adow and its GPIO counterpart (LTC6812/13 only). Default is PullUp unset meaning that the current sink (pulldown) is active during Open Wire check. Running command with this enabled activates current source (pullup) during Open Wire check

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors