HasSTConfig

Trait HasSTConfig 

pub trait HasSTConfig: Into<u16> + From<u16> {
    // Provided method
    fn set_st_config(self, config: SelfTestConfig) -> Self { ... }
}
Marks all Commands that have a Selftest Config Option and provides a method to set the config

Provided Methods

fn set_st_config(self, config: SelfTestConfig) -> Self

Defines the Selftest Config for digital filter selftest commands Statst, Axst and Cvst.

Selftest provides a known bitstream to the digital filters in the IC. If these Filter work correctly we expect a given result in the output registers. If the Registers do not provide the epxeted results digital filters work not correctly and measurement results can not be trusted

For exepcted result of this Selftest see SelfTestConfig

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors