pub trait HasDCPOption: Into<u16> + From<u16> {
// Provided method
fn set_dcp_option(self) -> Self { ... }
}Expand description
Marks all Commands implementing the DCP Option and provides method to set DCP
Default Command DCP is NOT set. With this call DCP Option is set and Discharge Permitted during measurememt
From Datsheet: If the discharge permitted (DCP) bit is high at the time of a cell measurement command, the S pin discharge states do not change during cell measurements. If the DCP bit is low, S pin discharge states will be disabled while the corresponding cell or adjacent cells are being measured.
Provided Methods
fn set_dcp_option(self) -> Self
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".