pub trait HasStatusChannelConfig: Into<u16> + From<u16> {
// Provided method
fn set_channel_config(self, config: StatusChannelConfig) -> Self { ... }
}Expand description
Marks all Commands that have a Channel Config for the Status ADCs and provides method to set the channel config
Provided Methods
Sourcefn set_channel_config(self, config: StatusChannelConfig) -> Self
fn set_channel_config(self, config: StatusChannelConfig) -> Self
Sets the channel config for the Status conversion command. Not setting anything Defaults to StatusChannelConfig::AllStatus
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".